@@ -1,26 +1,25 @@
 sub showProfile{
-my $sTitle  = translate('userprofile');
 my $hrUser  = $m_oDatabase->fetch_hashref("select * from  users where user = '$m_sUser'");
 $m_sContent .= qq|
-<div class="ShowTables">|.translate('password').qq| dsdf<form name="login" id="loginForm" target="_parent" method="get" name="saveProfile"  onsubmit="submitForm(this,'saveProfile','saveProfile');return false;">
+<div class="ShowTables" style="margin-top:4%;padding:4%;width:92%;"><form name="changePassword" target="_parent" method="get" onsubmit="submitForm(this,'saveProfile','saveProfile');return false;">
 <label for="user">|.translate('name').qq|</label>
 <br/>
-<input type="text" id="user" data-regexp=").'/^\w{4,100}$/'.qq(" data-error="$wrong_username_text" data-right="$right_username_text" name="user" value="$hrUser->{user}" size="18" maxlength="25" style="width:80%" align="left">
+<input type="text" id="user" data-regexp=").'/^\w{4,100}$/'.qq(" data-error="$wrong_username_text" data-right="$right_username_text" name="user" value="$hrUser->{user}">
 <br/>
 <label for="password">|.translate('password').qq|</label>
 <br/>
-<input type="password" data-regexp="/.{6,50}/" data-error="$wrong_passwort_text"  data-right="$right_passwort_text" id="password" name="pass" value ="" style="width:80%" maxlength="50" alt="password" align="left"/>
+<input type="password" data-regexp="/.{6,50}/" data-error="$wrong_passwort_text"  data-right="$right_passwort_text" id="password" name="pass"/>
 <br/>
 <label for="newpass">|.translate('newpass').qq|</label>
 <br/>
-<input type="password" data-regexp="/.{6,50}/" data-error="$wrong_passwort_text"  data-right="$right_passwort_text" id="password" name="newpass" value ="" style="width:80%" maxlength="50" alt="password" align="left"/>
+<input type="password" data-regexp="/.{6,50}/" data-error="$wrong_passwort_text"  data-right="$right_passwort_text" id="password" name="newpass"/>
 <br/>
 <label for="retry">|.translate('retry').qq|</label>
 <br/>
-<input type="password" data-regexp="/.{6,50}/" data-error="$wrong_passwort_text"  data-right="$right_passwort_text" id="password" name="retry" value ="" style="width:80%" maxlength="50" alt="password" align="left"/>
+<input type="password" data-regexp="/.{6,50}/" data-error="$wrong_passwort_text"  data-right="$right_passwort_text" id="password" name="retry"/>
 <br/>
 <br/>
-<input type="submit"  name="submit" value="|.translate('save').qq|" size="15" maxlength="15" alt="submit" align="left"/>
+<input type="submit"  name="submit" value="|.translate('save').qq|"/>
 <input type="hidden" name="action" value="saveProfile"/>
 </form></div>
 |;
@@ -49,11 +48,11 @@ sub saveProfile
     }
     $m_sContent .= '<div class="showTables"><b>' . translate('done') . '</b><br/>
     <table align="center" border="0" cellpadding="0" cellspacing="0" width="100%" align="center">
-    <tr><td align="left">' . translate('newpass') . '</td><td>' . $newpass . '</td></tr>' if ($pwChanged);
+    <tr><td >' . translate('newpass') . '</td><td>' . $newpass . '</td></tr>' if ($pwChanged);
     $m_sContent .= '</table>'
       . a(
           {
-           href  => "javascript:requestURI('$ENV{SCRIPT_NAME}?action=profile','dynamicLink','profile')",
+           href  => "javascript:requestURI('$ENV{SCRIPT_NAME}?action=showProfile','showProfile','showProfile')",
            class => 'links'
           },
           translate('next')
