@@ -1,37 +1,37 @@
 $VAR1 = {
-          'scriptAlias' => 'cgi-bin',
-          'floodtime' => 10,
-          'cgi' => {
-                     'bin' => '/var/www/cgi-bin',
-                     'DocumentRoot' => '/var/www/htdocs',
-                     'expires' => '+1y',
-                     'cookiePath' => '/',
-                     'serverName' => 'http://localhost',
-                     'title' => 'MySQL::Admin',
-                     'style' => 'mysql',
-                     'alias' => 'cgi-bin'
-                   },
-          'config' => '/var/www/cgi-bin/config/settings.pl',
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
           'database' => {
-                          'name' => 'LZE',
-                          'password' => 'keinz',
                           'CurrentUser' => 'root',
-                          'host' => 'localhost',
-                          'CurrentDb' => 'LZE',
                           'CurrentHost' => 'localhost',
+                          'host' => 'localhost',
                           'user' => 'root',
+                          'CurrentDb' => 'LZE',
+                          'password' => 'keinz',
+                          'name' => 'LZE',
                           'CurrentPass' => 'keinz'
                         },
           'language' => 'en',
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
-          'version' => '0.72',
+          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
+          'floodtime' => 10,
+          'scriptAlias' => 'cgi-bin',
+          'cgi' => {
+                     'style' => 'mysql',
+                     'bin' => '/var/www/cgi-bin',
+                     'expires' => '+1y',
+                     'DocumentRoot' => '/var/www/htdocs',
+                     'cookiePath' => '/',
+                     'alias' => 'cgi-bin',
+                     'title' => 'MySQL::Admin',
+                     'serverName' => 'http://localhost'
+                   },
           'admin' => {
+                       'email' => 'dirk.lze@gmail.com',
                        'name' => 'Lindner',
                        'firstname' => 'Dirk',
-                       'password' => 'testpass',
-                       'email' => 'dirk.lze@gmail.com'
+                       'password' => 'testpass'
                      },
-          'session' => '/var/www/cgi-bin/config/session.pl'
+          'session' => '/var/www/cgi-bin/config/session.pl',
+          'version' => '0.73',
+          'translate' => '/var/www/cgi-bin/config/translate.pl'
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
