@@ -99,6 +99,13 @@ $VAR1 = {
 		    'codenotcheckedfileerror'=> '',
 		    'failednotindatabase'=> '',
 		    'failedinvalidcode'=> 'Failed invalid code',
+                    'RenameTable'   => 'rename Table',
+                    'showeditindex' => 'New Index',
+                    'shownewrow'    => 'New Row',
+		    'showProfile'=> 'Profile',
+		    'saveProfile'=> 'Profile',
+		    'retry'=> 'Retry',
+		    'newpass'=> 'New Password',
                   },
           'de' => {
                     'host' => 'host',
@@ -120,11 +127,11 @@ $VAR1 = {
                     'user' => 'Benutzer',
                     'reg' => 'Registrieren',
                     'showcreatedatabase' => 'Datenbank',
-                    'select_all' => 'Alle ausw&#228;hlen',
+                    'select_all' => 'Alle auswählen',
                     'drop_database' => 'Datenbank löschen',
                     'regexp' => 'Regulärer Ausdruck',
-                    'execsql' => 'Sql ausf&#252;hren',
-                    'showcreatetable' => 'Tabelle&#160;erstellen',
+                    'execsql' => 'Sql ausführen',
+                    'showcreatetable' => 'Tabelle erstellen',
                     'after' => 'nach',
                     'showusers' => 'Benutzer',
                     'login' => 'Anmelden',
@@ -146,7 +153,7 @@ $VAR1 = {
                     'createnewtable' => 'Neue Tabelle',
                     'export' => 'Exportieren',
                     'optimizetable' => 'Optimieren',
-                    'indexover' => 'Index &#252;ber',
+                    'indexover' => 'Index über',
                     'wrong_username_text' => 'Der Benutzername muss mindestens 3 Zeichen lange sein und darf nur Ziffern und Buchstaben enthalten.',
                     'changecurrentdb' => 'Benutzer wechseln',
                     'insertafter' => 'Einfügen',
@@ -154,24 +161,27 @@ $VAR1 = {
                     'save' => 'Speichern',
                     'right_passwort_text' => 'Ok',
                     'rowsineffect' => 'betroffene Datensätze',
-                    'edittable' => 'Bearbeiten.',
+                    'edittable' => 'Bearbeiten',
                     'sql' => 'SQL',
                     'createdatabase' => 'Neue Datenbank',
                     'showdatabases' => 'Datenbanken',
                     'comment' => 'Kommentar',
                     'repair' => 'Reparieren',
                     'password' => 'Passwort',
-                    'editentry' => 'Eintrag bearbeiten',
+                    'editentry' => 'Bearbeiten',
                     'name' => 'Name',
                     'endtable' => 'am ende',
                     'databases' => 'Datenbanken',
-                    'collation' => 'Collation',
+                    'collation' => 'Kollation',
                     'size' => 'Größe',
                     'newentry' => 'Neuer Eintrag',
                     'edit' => 'Bearbeiten',
                     'wrong_passwort_text' => 'Das Passwort muss mindestens 6 zeichen lang sein',
                     'edittableprops' => 'Bearbeiten',
                     'rename' => 'Umbenennen',
+                    'RenameTable' => 'Tabelle umbenennen',
+                    'showeditindex' => 'Index erstellen',
+                    'shownewrow' => 'Neue Zeile',
                     'database' => 'Datenbank',
                     'editmysqluserrights' => 'Benutzerrechte',
                     'connect' => 'Verbinden',
@@ -200,6 +210,10 @@ $VAR1 = {
 		    'codenotcheckedfileerror'=> '',
 		    'failednotindatabase'=> '',
 		    'failedinvalidcode'=> 'Falscher Code',
+		    'showProfile'=> 'Profile',
+		    'saveProfile'=> 'Profile',
+		    'retry'=> 'Wiederhohlen',
+		    'newpass'=> 'Neues Passwort',
                   }
         };
 $lang =$VAR1;
\ No newline at end of file
