@@ -7,7 +7,7 @@ CREATE TABLE `actions` (
   `sub` varchar(25) NOT NULL DEFAULT 'main',
   `id` int(11) NOT NULL AUTO_INCREMENT,
   PRIMARY KEY (`id`)
-) ENGINE=MyISAM AUTO_INCREMENT=149 DEFAULT CHARSET=utf8;
+) ENGINE=MyISAM AUTO_INCREMENT=150 DEFAULT CHARSET=utf8;
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('showLogin','exploit.pl','','0','tables','main','147');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AddFulltext','tables.pl','AddFulltext','5','tables','AddFulltext','62');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AnalyzeTable','tables.pl','AnalyzeTable','5','tables','AnalyzeTable','63');
@@ -69,13 +69,14 @@ INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values(
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('CreateUser','tables.pl','CreateUser','5','tables','CreateUser','130');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DeleteUser','tables.pl','DeleteUser','5','tables','DeleteUser','131');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropDatabase','tables.pl','DropDatabase','5','tables','DropDatabase','132');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowDatabases','tables.pl','ShowDatabases','5','tables','ShowDatabases','133');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowDatabases','tables.pl','ShowDatabases','5','tables exploit','ShowDatabases','133');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowProcesslist','tables.pl','ShowProcesslist','5','tables','ShowProcesslist','134');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowVariables','tables.pl','ShowVariables','5','tables','ShowVariables','135');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('translate','translate.pl','translate','5','tables','main','141');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowProcesslist','tables.pl','processlist','5','tables','ShowProcesslist','143');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowVariables','tables.pl','ShowVariables','5','tables','ShowVariables','144');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('searchDatabase','tables.pl','searchDatabase','5','tables','searchDatabase','145');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('saveProfile','profile.pl','Profile','5','','saveProfile','149');
 
 CREATE TABLE `box` (
   `file` varchar(100) NOT NULL DEFAULT '',
@@ -87,6 +88,7 @@ CREATE TABLE `box` (
 ) ENGINE=MyISAM AUTO_INCREMENT=12 DEFAULT CHARSET=utf8;
 INSERT INTO `box` (`file`,`right`,`name`,`outId`,`id`) values('tables.pl','5','database','menuBar','10');
 INSERT INTO `box` (`file`,`right`,`name`,`outId`,`id`) values('exploit.pl','0','exploit','content','11');
+
 CREATE TABLE `exploit` (
   `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
   `referer` text NOT NULL,
@@ -98,6 +100,7 @@ CREATE TABLE `exploit` (
   UNIQUE KEY `id` (`id`),
   FULLTEXT KEY `remote_addr` (`remote_addr`)
 ) ENGINE=MyISAM DEFAULT CHARSET=utf8;
+
 CREATE TABLE `querys` (
   `title` varchar(100) NOT NULL DEFAULT '',
   `description` text NOT NULL,
@@ -106,6 +109,7 @@ CREATE TABLE `querys` (
   `id` int(11) NOT NULL AUTO_INCREMENT,
   PRIMARY KEY (`id`)
 ) ENGINE=MyISAM DEFAULT CHARSET=utf8;
+
 CREATE TABLE `reserved_words` (
   `reserved_word` varchar(50) DEFAULT NULL,
   `id` int(11) NOT NULL AUTO_INCREMENT,
@@ -343,5 +347,4 @@ CREATE TABLE `users` (
   `id` int(11) NOT NULL AUTO_INCREMENT,
   PRIMARY KEY (`id`)
 ) ENGINE=MyISAM AUTO_INCREMENT=7 DEFAULT CHARSET=utf8;
-INSERT INTO `users` (`pass`,`user`,`right`,`sid`,`ip`,`id`) values('guest','guest','0','123','dd','1');
-INSERT INTO `users` (`pass`,`user`,`right`,`sid`,`ip`,`id`) values('fe7374a18d3f8ca9547e49aa39a2dd67','admin','5','3cd93fcddf701b48bf4b1766c856a489','127.0.0.1','2');
\ No newline at end of file
+INSERT INTO `users` (`pass`,`user`,`right`,`sid`,`ip`,`id`) values('guest','guest','0','123','dd','1');
\ No newline at end of file
